#include "md3tomdl.h"
#include "mdlexport.h"
#include "md3import.h" //needs to access md3 structs
#include "pcxload.h"
#include "textparse.h"

int32_t main(int32_t argc, const char* argv[])
{
	if(argc < 2)
	{
		std::cout << "Please specify a text file" << std::endl;
		return 1;
	}

	std::ifstream cfile(argv[1]);
	if(!cfile)
	{
		std::cout << "file not found/error reading file" << std::endl;
		return 2;
	}
	options settings;
	parse_commands(cfile, settings);
	cfile.close();

	if(settings.mdlpath.empty())
		settings.mdlpath = "output.mdl";

	std::cout << "input: \"" << settings.md3path << "\"" << std::endl;
	std::cout << "skin:  \"" << settings.skinpath << "\"" << std::endl;
	std::cout << "output:  \"" << settings.mdlpath << "\"" << std::endl;

	std::ifstream q3input;
	q3input.open(settings.md3path.c_str(), std::ios_base::binary);
	if(!q3input.good())
	{
		std::cout << "Could not open md3 file" << std::endl;
		return 2;
	}

	//load this file
	q3_model q3format;
	if(!parse_q3model(q3input, q3format))
		return 3;
	q3input.close();
	
	//load the skin
	std::ifstream pcxinput;
	skin q1skin;
	pcxinput.open(settings.skinpath.c_str(), std::ios_base::binary);
	if(pcxinput.good())
	{
		loadskin(pcxinput,q1skin);
	}//the export code handles the case when no skindata is loaded here, not a fatal error
	pcxinput.close();

	//export to mdl
	std::ofstream q1output;
	q1output.open(settings.mdlpath.c_str(), std::ios_base::binary);
	if(!q1output.good())
	{
		std::cout << "Output file experienced a file error, conversion terminated";
		return 3;
	}
	export_to_mdl(q1output, q3format, q1skin, settings);
	q1output.close();
	
	return 0;
}
